Index: service/rawdatastore/datastore.go |
diff --git a/helper/datastore.go b/service/rawdatastore/datastore.go |
similarity index 66% |
rename from helper/datastore.go |
rename to service/rawdatastore/datastore.go |
index 038dbbbe92f41cfa293b86fdc5f77910f033ccf8..6d7acb0a20f9c4736f35a2b21ca01de3d95281ea 100644 |
--- a/helper/datastore.go |
+++ b/service/rawdatastore/datastore.go |
@@ -2,22 +2,18 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-// HEAVILY adapted from github.com/golang/appengine/datastore |
- |
-package helper |
+package rawdatastore |
import ( |
"reflect" |
- |
- "github.com/luci/gae" |
) |
// GetPLS resolves o into a gae.DSStructPLS. o must be a pointer to a |
// struct of some sort. |
-func GetPLS(o interface{}) gae.DSPropertyLoadSaver { |
+func GetPLS(o interface{}) PropertyLoadSaver { |
v := reflect.ValueOf(o) |
if v.Kind() != reflect.Ptr || v.Elem().Kind() != reflect.Struct { |
- return &structPLS{c: &structCodec{problem: gae.ErrDSInvalidEntityType}} |
+ return &structPLS{c: &structCodec{problem: ErrInvalidEntityType}} |
} |
v = v.Elem() |
t := v.Type() |
@@ -2,22 +2,18 @@ |
) |
-// GetPLS resolves o into a gae.DSStructPLS. o must be a pointer to a |
+// GetPLS resolves o into a PropertyLoadSaver. o must be a pointer to a |
// struct of some sort. |